//[mahjong-utils](../../../../index.md)/[mahjongutils.hora](../../index.md)/[HoraArgsErrorInfo](../index.md)/[tilesIsEmpty](index.md)

# tilesIsEmpty

[common]\
[tilesIsEmpty](index.md)

## Properties

| Name | Summary |
|---|---|
| [message](../message.md) | [common]<br>open override val [message](../message.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [name](../../../mahjongutils.shanten/-furo-chance-shanten-args-error-info/tiles-num-illegal/index.md#-372974862%2FProperties%2F1581026887) | [common]<br>val [name](../../../mahjongutils.shanten/-furo-chance-shanten-args-error-info/tiles-num-illegal/index.md#-372974862%2FProperties%2F1581026887): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../../../mahjongutils.shanten/-furo-chance-shanten-args-error-info/tiles-num-illegal/index.md#-739389684%2FProperties%2F1581026887) | [common]<br>val [ordinal](../../../mahjongutils.shanten/-furo-chance-shanten-args-error-info/tiles-num-illegal/index.md#-739389684%2FProperties%2F1581026887): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
